@@ -43,7 +43,8 @@ def make_input_ppi_db(filein,
                       this_time, 
                       nominal_ppi_elevation, 
                       min_range_in_ppi, 
-                      max_range_in_ppi):
+                      max_range_in_ppi,
+                      obs_nyquist):
 
   """make a separate db for one PPI
 
@@ -56,7 +57,7 @@ def make_input_ppi_db(filein,
      nominal_ppi_elevation  : nominal elevation
      min_range_in_ppi       : min range in PPI
      max_range_in_ppi       : max range in PPI
-
+     obs_nyquist            : Nyquist for QC
    output: 
      sqlite connection to the created db
 
@@ -90,8 +91,9 @@ def make_input_ppi_db(filein,
                   WHERE
                     id_stn = ?   
                     and time = ? 
-                    and round(nominal_ppi_elevation, 1) = ? ;"""
-  conn_ppi_db.execute(order_sql, (stn, this_time, nominal_ppi_elevation))
+                    and round(nominal_ppi_elevation, 1) = ? 
+                    and nyquist >= ?;"""
+  conn_ppi_db.execute(order_sql, (stn, this_time, nominal_ppi_elevation, obs_nyquist))
   #select associated data entries
   order_sql = """ INSERT into data 
                   SELECT
@@ -373,7 +375,9 @@ def create_info_midas_tables(filein,
                               conn_pathfileout, 
                               n_rays,        
                               delta_range,
-                              ops_run_name):
+                              ops_run_name,
+                              obs_percentage, 
+                              obs_nyquist):
   """ Create header entry
 
   A header is created matching a bunch of entries in data table
@@ -384,6 +388,8 @@ def create_info_midas_tables(filein,
     n_rays        : number of rays 
     delta_range   : delta range of the boxes
     ops_run_name  : name of operational run
+    obs_percentage:
+    obs_nyquist   :
   output:
     Nothing
     info table entry is written in output sqlite file
@@ -400,6 +406,19 @@ def create_info_midas_tables(filein,
                  SELECT * 
                    from  db_all.info """
   conn_pathfileout.execute( order_sql)
+
+  order_sql =""" INSERT  into  info (
+                   NAME, DESCRIPTION, UNIT) values
+                 (?,?,?)"""
+  conn_pathfileout.execute( order_sql, ('Maximun nyquist', 'Maximum Nyquist permitted',obs_nyquist,))
+ 
+
+  order_sql =""" INSERT  into  info (
+                   NAME, DESCRIPTION, UNIT) values
+                 (?,?,?)"""
+  conn_pathfileout.execute( order_sql, ('Minus percentage of observation in the box', 'percentage of observation in the box to average', obs_percentage,))
+
+
   order_sql =""" UPDATE  info SET DESCRIPTION = REPLACE(DESCRIPTION,'OFF','ON') where name = 'SUPEROBBING';"""
   conn_pathfileout.execute( order_sql)
   order_sql =""" UPDATE  info SET DESCRIPTION = ? where name = 'SUPEROBBING_NUMBER_RAYS' ;"""
@@ -433,6 +452,7 @@ def superobs(filein,
              ray_list, 
              ops_run_name, 
              obs_percentage,
+             obs_nyquist,
              timer=False):
 
   """ Average  a volume scan
@@ -516,7 +536,8 @@ def superobs(filein,
                                     hhmiss_nopad, 
                                     nominal_ppi_elevation, 
                                     min_range_in_ppi, 
-                                    max_range_in_ppi)
+                                    max_range_in_ppi,
+                                    obs_nyquist)
 
     #temporarily attach ppi db to output file
     conn_filememory.execute('ATTACH DATABASE "file::memory:?cache=shared" AS db_ppi') 
@@ -551,7 +572,7 @@ def superobs(filein,
             sum_elev_ray   += sum_elev_box
             id_data = (rng.integers(maxsize, size=1))[0].tolist()
             number_obs_percentage +=number_obs_percentage 
-            number_obs_ray_percentage += number_obs_percentage
+            number_obs_ray_percentage += number_obs_box
       
       # if any data was found in ray, create header entry matching average bins
       # already entered in data table
@@ -701,7 +722,8 @@ def compute_average(center_time,
          n_rays, 
          delta_range,
          n_cpus,
-         obs_percentage):
+         obs_percentage,
+         obs_nyquist):
   """launch computation of average volums scans, possibly in parallel
 
   args:
@@ -717,6 +739,7 @@ def compute_average(center_time,
     delta_range  : delta range of the boxes
     n_cpus       : number of cpus for parallel execution, with n_cpus=1 joba are launched sequentially and dask is not invoked 
     obs_percentage : percentage of observation in the box to average
+    obs_nyquist : Nyquist for QC
   output:
     Nothing
     Average sqlite file(s) are created with the '_thin' suffix
@@ -746,8 +769,11 @@ def compute_average(center_time,
   for this_file in infile_list:
     with sqlite3.connect(this_file) as conn_loops:
       # list of radars in the file
-      avail_radar_list  = [ stn[0] for stn in conn_loops.execute("select distinct ID_STN from header order by 1;").fetchall() ]
-   
+
+      try:
+        avail_radar_list  = [ stn[0] for stn in conn_loops.execute("select distinct ID_STN from header order by 1;").fetchall() ]
+      except:
+        continue
      
       for this_radar in avail_radar_list:
         #select radars if desired radar_list is specified
@@ -763,7 +789,7 @@ def compute_average(center_time,
           #only include date in assimilation window
           if (this_date > window_t0) and (this_date <= window_tf):
             vol_scan_list.append( {'file':this_file, 'radar':this_radar, 'date':this_date} )
-  
+
   if len(vol_scan_list) == 0:
     raise RuntimeError('List of volume scan to process is empty. Check that files are available and search criteria are correct.')
 
@@ -784,7 +810,7 @@ def compute_average(center_time,
     this_radar = vol_scan_list[0]['radar']
     this_date  = vol_scan_list[0]['date']
     superobs(this_file, this_radar, this_date, 
-             pathfileout, averaging_template, ops_run_name, obs_percentage, timer=True)
+             pathfileout, averaging_template, ops_run_name, obs_percentage, obs_nyquist, timer=True)
     tc_1 = time.time()
 
   else:
@@ -794,7 +820,7 @@ def compute_average(center_time,
       print('Serial execution')
       for vscan in vol_scan_list:
         superobs(vscan['file'] ,vscan['radar'], vscan['date'], 
-                 pathfileout, averaging_template, ops_run_name, obs_percentage)
+                 pathfileout, averaging_template, ops_run_name, obs_percentage, obs_nyquist)
     else:
       print(f'Compute {len(vol_scan_list)} volume scans in parallel')
       with tempfile.TemporaryDirectory() as tmpdir:
@@ -807,12 +833,12 @@ def compute_average(center_time,
           #delay data 
           averaging_template = dask.delayed(averaging_template)
           joblist = [delayed(superobs)(vscan['file'], vscan['radar'], vscan['date'], 
-                                       pathfileout, averaging_template, ops_run_name, obs_percentage) for vscan in vol_scan_list]
+                                       pathfileout, averaging_template, ops_run_name, obs_percentage, obs_nyquist) for vscan in vol_scan_list]
           dask.compute(joblist)
    
     sample_file  = vol_scan_list[0]['file']
     # create info and resume_tables in fileout
-    create_info_midas_tables(sample_file, conn_pathfileout, n_rays, delta_range, ops_run_name)   
+    create_info_midas_tables(sample_file, conn_pathfileout, n_rays, delta_range, ops_run_name, obs_percentage, obs_nyquist)   
     # improve searches with index tables
     create_index_tables_idobs_iddata(conn_pathfileout)
     # collision_test
@@ -838,9 +864,10 @@ def arg_call():
     parser.add_argument('--timing',       action="store_true",             help="Average only one PPI for time analysis" ) 
     parser.add_argument('--ops_run_name', default='N1',        type=str,   help="Name of operational run (will show up in rdb4_schema)" ) 
     parser.add_argument('--n_rays',       default=20,          type=int,   help="Number of rays for averaging" )
-    parser.add_argument('--delta_range',  default=5000.,      type=float, help="Delta_range  for averaging" )
+    parser.add_argument('--delta_range',  default=5000.,       type=float, help="Delta_range  for averaging" )
     parser.add_argument('--n_cpus',       default=1,           type=int,   help="Number of rays for averaging" )
-    parser.add_argument('--obs_percentage',default=50,          type=int,   help="Percentage of observation in the box to average" )
+    parser.add_argument('--obs_percentage',default=50,         type=float, help="Percentage of observation in the box to average" )
+    parser.add_argument('--obs_nyquist'   ,default=100,        type=float, help="Nyquist for QC" )
 
     args = parser.parse_args()
 
@@ -900,7 +927,7 @@ def arg_call():
 
     if not os.path.isdir(args.pathout):
       os.mkdir(args.pathout)
-
+    print ( args.desired_radar_list)
     #sys.exit is used to the return status of main is catched and passed to caller
     sys.exit(compute_average(args.center_time,
                   args.window_width,
@@ -913,7 +940,8 @@ def arg_call():
                   args.n_rays, 
                   args.delta_range, 
                   args.n_cpus,
-                  args.obs_percentage))
+                  args.obs_percentage,
+                  args.obs_nyquist))
 
 if __name__ == '__main__':
     arg_call()
